
clear screen
----------------------------------------------------------

-- Drop user TEST if it exists - Cleaning Up First
 
----------------------------------------------------------

conn / as sysdba

set echo on
set termout on
set feed on

drop user test cascade;

purge dba_recyclebin;

create user test identified by test;
 
grant xdbadmin, dba to test;
 
 
connect test/test

set echo on
set termout on
set feed on
 

var schemaPath varchar2(256)
var schemaURL  varchar2(256)

pause
 
clear screen

begin
  :schemaURL := 'http://www.myserver.com/root.xsd';
  :schemaPath := '/public/root.xsd';
end;
/


----------------------------------------------------------

-- Create an XML Schema root.xsd in directory /public/

----------------------------------------------------------
 
declare
  res boolean;
  xmlSchema xmlType := xmlType(
'<?xml version="1.0" encoding="UTF-8"?>
 <xs:schema xmlns:xs="http://www.w3.org/2001/XMLSchema"
            xmlns:xdb="http://xmlns.oracle.com/xdb"
            xmlns="http://www.myserver.com/root.xsd" targetNamespace="http://www.myserver.com/root.xsd"
            elementFormDefault="qualified" 
            attributeFormDefault="unqualified"
            xdb:storeVarrayAsTable="true">
 <xs:element name="ROOT" xdb:defaultTable="ROOT_TABLE" xdb:maintainDOM="false">
  <xs:annotation>
   <xs:documentation>Example XML Schema</xs:documentation>
  </xs:annotation>
  <xs:complexType xdb:maintainDOM="false">
   <xs:sequence>
    <xs:element name="ID" type="xs:integer" xdb:SQLName="ID"/>
    <xs:element ref="INFO" xdb:SQLInline="false" />
   </xs:sequence>
  </xs:complexType>
 </xs:element>
 <xs:element name="INFO" xdb:SQLName="INFO_TYPE">
  <xs:complexType xdb:maintainDOM="false">
   <xs:sequence>
    <xs:element name="INFO_ID" type="xs:integer" xdb:SQLName="TYPE_INFO_ID"/>
    <xs:element name="INFO_CONTENT" 
                xdb:SQLName="TYPE_INFO_CONTENT" type="xs:string"/>
   </xs:sequence>
  </xs:complexType>
 </xs:element>
</xs:schema>');
begin
if (dbms_xdb.existsResource(:schemaPath)) then
    dbms_xdb.deleteResource(:schemaPath);
end if;
 res := dbms_xdb.createResource(:schemaPath,xmlSchema);
end;
/
 
pause

clear screen

----------------------------------------------------------

-- Selecting repository files and folders via XDBUriType

----------------------------------------------------------

select xdbURIType ('/public/root.xsd').getClob()
from   dual;

pause

clear screen

begin
  :schemaURL := 'http://www.myserver.com/root.xml';
  :schemaPath := '/public/root.xml';
end;
/
 

----------------------------------------------------------

-- Create an XML Document root.xml in directory /public/
 
----------------------------------------------------------

declare
  res boolean;
  xmlSchema xmlType := xmlType(
'<?xml version="1.0" encoding="UTF-8"?>
<ROOT xmlns="http://www.myserver.com/root.xsd">
 <ID>0</ID>
 <INFO>
   <INFO_ID>0</INFO_ID>
   <INFO_CONTENT>Text</INFO_CONTENT>
 </INFO>
</ROOT>');
begin
if (dbms_xdb.existsResource(:schemaPath)) then
    dbms_xdb.deleteResource(:schemaPath);
end if;
 res := dbms_xdb.createResource(:schemaPath,xmlSchema);
end;
/
 
pause

clear screen

----------------------------------------------------------

-- Selecting repository files and folders via XDBUriType

----------------------------------------------------------

select xdbURIType ('/public/root.xml').getClob()
from   dual;

pause


clear screen

----------------------------------------------------------

-- Delete an XML schema in the registry if it exists

----------------------------------------------------------


call DBMS_XMLSCHEMA.deleteSchema('http://www.myserver.com/root.xsd', 4);

commit;

select * from tab;

alter session set events='31098 trace name context forever';

BEGIN 
 DBMS_XMLSCHEMA.registerSchema
 (SCHEMAURL => 'http://www.myserver.com/root.xsd', 
  SCHEMADOC => xdbURIType('/public/root.xsd').getClob(), 
  LOCAL     => FALSE, -- local 
  GENTYPES  => TRUE,  -- generate object types 
  GENBEAN   => FALSE, -- no java beans 
  GENTABLES => TRUE,  -- generate object tables 
  OWNER     => USER
 ); 
END; 
/ 
 
commit;

select * from tab;

pause
 
clear screen
 
----------------------------------------------------------

-- Insert some data with XDBURIType

----------------------------------------------------------
 
DECLARE
   XMLData xmlType := xmlType(xdbURIType ('/public/root.xml').getClob());
BEGIN
  for i in 1..10
  loop
      insert into ROOT_TABLE
      VALUES
      (XMLData);
  end loop;
END;
/

commit;

-- randomize the data a little
 
update ROOT_TABLE
set object_value = updateXML(object_value,
                            '/ROOT/ID/text()',
                            substr(round(dbms_random.value*100),0,2)
                            );
 
 
 
update ROOT_TABLE
set object_value = updateXML(object_value,
                            '/ROOT/INFO/INFO_ID/text()',
                            substr(round(dbms_random.value*100),0,2)
                            );

commit;
 
pause 

clear screen 

----------------------------------------------------------

-- End Result

----------------------------------------------------------
 
select count(*) from root_table;

select * from root_table where rownum < 5;
