-- Thanks to Keith Matthew

clear screen

----------------------------------------------------------

-- Drop user EVENT if it exists - Cleaning Up First
 
----------------------------------------------------------

conn / as sysdba

set termout on
set feed on
set lines 40
set long 10000000
set serveroutput on
set echo on

call dbms_xdb.deleteResource('/home/EVENT',4);
commit;
call dbms_xdb.deleteResource('/public/event.xml',4);
commit;
 
drop user event cascade;
 
create user event identified by event account unlock;
 
grant dba, xdbadmin to event;
 
alter session set current_schema=EVENT;
 
-- Create logging table
 
create table event_logging
( DTIME     DATE
, EVENT     VARCHAR2(100)
);

pause

clear screen 

----------------------------------------------------------

-- Create folder structure /home/EVENT
 
----------------------------------------------------------

declare
  result boolean;
begin
  if (dbms_xdb.existsResource('/home/EVENT')) 
  then
    dbms_xdb.deleteResource('/home/EVENT',dbms_xdb.DELETE_RECURSIVE_FORCE);
  end if;
  commit;
  result := dbms_xdb.createFolder('/home/EVENT');
  dbms_xdb.setACL('/home/EVENT','/sys/acls/bootstrap_acl.xml');
end;
/
commit
/
 
pause

clear screen 

----------------------------------------------------------

-- Add Event handlers
 
----------------------------------------------------------
 
create or replace PACKAGE EVENT_PACKAGE 
AS
    PROCEDURE handlePostLinkIn (eventObject DBMS_XEVENT.XDBRepositoryEvent);
END EVENT_PACKAGE;
/
create or replace PACKAGE BODY EVENT_PACKAGE 
AS
  PROCEDURE handlePostLinkIn (eventObject DBMS_XEVENT.XDBRepositoryEvent) AS
    BEGIN
        insert into event_logging 
        ( DTIME
        , EVENT
        )
        values
        ( SYSDATE
        , 'XML File created in Repository'
        );
    END;
END;
/
 
pause

clear screen 

----------------------------------------------------------

-- Associate event handlers with the directory
 
----------------------------------------------------------
 
DECLARE
  b        BOOLEAN;
  resfile  VARCHAR2(100)   := '/public/event.xml';
BEGIN
 
  BEGIN  -- Remove any references to the Resource Config file

    DBMS_RESCONFIG.DELETERESCONFIG(
      respath      => '/home/EVENT',
      rcpath       => resfile,
      deleteOption => DBMS_RESCONFIG.DELETE_RECURSIVE
    );
 
    EXCEPTION
        WHEN OTHERS THEN
            NULL;
  END;
 
  --Create the config file that references the event handlers and associates them with the Post-LinkIn event
 
  if (dbms_xdb.existsResource(resfile)) 
  then
    dbms_xdb.deleteResource(resfile, dbms_xdb.DELETE_RECURSIVE_FORCE);
  end if;
 
  b := DBMS_XDB.createresource(
    resfile,
 '<ResConfig xmlns="http://xmlns.oracle.com/xdb/XDBResConfig.xsd" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
   xsi:schemaLocation="http://xmlns.oracle.com/xdb/XDBResConfig.xsd  http://xmlns.oracle.com/xdb/XDBResConfig.xsd">
   <event-listeners>
     <listener>
       <description>Logging of created xml files in target directory</description>
       <schema>EVENT</schema>
       <source>EVENT_PACKAGE</source>
       <language>PL/SQL</language>
       <events>
         <Post-LinkIn/>
       </events>
       <pre-condition>
         <existsNode>
           <XPath>/Resource[ContentType="text/xml"]</XPath>
         </existsNode>
       </pre-condition>
     </listener>
   </event-listeners>
 </ResConfig>');
 
 DBMS_RESCONFIG.APPENDRESCONFIG(
    respath      => '/home/EVENT',
    rcpath       => resfile,
    appendoption => DBMS_RESCONFIG.APPEND_RESOURCE
  );
 
  COMMIT;
END;
/
 
commit;

pause

clear screen 

-----------------------------------------------------------

-- Test if event gets triggered by drag and dropping a file
 
-----------------------------------------------------------
  
select * from event.event_logging;

-- ==> drop XML, XSD and other files into /home/EVENT

pause
 
select * from event.event_logging;
